@@ -1,23 +1,21 @@
 package Net::DNS::Parameters;
 
-use strict;
-use warnings;
-
-our $VERSION = (qw$Id: Parameters.pm 1812 2020-10-07 18:09:53Z willem $)[2];
-
-
 ################################################
 ##
 ##	Domain Name System (DNS) Parameters
-##	(last updated 2020-07-20)
+##	(last updated 2021-03-08)
 ##
 ################################################
 
+use strict;
+use warnings;
+our $VERSION = (qw$Id: Parameters.pm 1832 2021-03-22 08:33:36Z willem $)[2];
 
 use integer;
 use Carp;
 
 use base qw(Exporter);
+
 our @EXPORT_OK = qw(
 		classbyname classbyval %classbyname
 		typebyname typebyval %typebyname
@@ -26,6 +24,7 @@ our @EXPORT_OK = qw(
 		ednsoptionbyname ednsoptionbyval
 		dsotypebyname dsotypebyval
 		);
+
 our %EXPORT_TAGS = (
 	class	   => [qw(classbyname classbyval)],
 	type	   => [qw(typebyname typebyval)],
@@ -112,7 +111,7 @@ my @typebyname = (
 	CDNSKEY	   => 60,					# RFC7344
 	OPENPGPKEY => 61,					# RFC7929
 	CSYNC	   => 62,					# RFC7477
-	ZONEMD	   => 63,					# draft-wessels-dns-zone-digest
+	ZONEMD	   => 63,					# RFC8976
 	SVCB	   => 64,					# draft-ietf-dnsop-svcb-https-00
 	HTTPS	   => 65,					# draft-ietf-dnsop-svcb-https-00
 	SPF	   => 99,					# RFC7208
@@ -127,7 +126,7 @@ my @typebyname = (
 	EUI48	   => 108,					# RFC7043
 	EUI64	   => 109,					# RFC7043
 	TKEY	   => 249,					# RFC2930
-	TSIG	   => 250,					# RFC-ietf-dnsop-rfc2845bis-09
+	TSIG	   => 250,					# RFC8945
 	IXFR	   => 251,					# RFC1995
 	AXFR	   => 252,					# RFC1035 RFC5936
 	MAILB	   => 253,					# RFC1035
@@ -172,17 +171,17 @@ my @rcodebyname = (
 	YXRRSET	  => 7,						# RFC2136
 	NXRRSET	  => 8,						# RFC2136
 	NOTAUTH	  => 9,						# RFC2136
-	NOTAUTH	  => 9,						# RFC-ietf-dnsop-rfc2845bis-09
+	NOTAUTH	  => 9,						# RFC8945
 	NOTZONE	  => 10,					# RFC2136
 	DSOTYPENI => 11,					# RFC8490
 	BADVERS	  => 16,					# RFC6891
-	BADSIG	  => 16,					# RFC-ietf-dnsop-rfc2845bis-09
-	BADKEY	  => 17,					# RFC-ietf-dnsop-rfc2845bis-09
-	BADTIME	  => 18,					# RFC-ietf-dnsop-rfc2845bis-09
+	BADSIG	  => 16,					# RFC8945
+	BADKEY	  => 17,					# RFC8945
+	BADTIME	  => 18,					# RFC8945
 	BADMODE	  => 19,					# RFC2930
 	BADNAME	  => 20,					# RFC2930
 	BADALG	  => 21,					# RFC2930
-	BADTRUNC  => 22,					# RFC-ietf-dnsop-rfc2845bis-09
+	BADTRUNC  => 22,					# RFC8945
 	BADCOOKIE => 23,					# RFC7873
 	);
 our %rcodebyval = reverse( BADSIG => 16, @rcodebyname );
@@ -205,7 +204,7 @@ my @ednsoptionbyname = (
 	PADDING		 => 12,					# RFC7830
 	CHAIN		 => 13,					# RFC7901
 	'KEY-TAG'	 => 14,					# RFC8145
-	'EXTENDED-ERROR' => 15,					# RFC-ietf-dnsop-extended-error-16
+	'EXTENDED-ERROR' => 15,					# RFC8914
 	'CLIENT-TAG'	 => 16,					# draft-bellis-dnsop-edns-tags
 	'SERVER-TAG'	 => 17,					# draft-bellis-dnsop-edns-tags
 	DEVICEID	 => 26946,				# https://docs.umbrella.com/developer/networkdevices-api/identifying-dns-traffic2
@@ -379,8 +378,9 @@ use constant EXTLANG => defined eval { require Net::DNS::Extlang };
 
 our $DNSEXTLANG = EXTLANG ? eval { Net::DNS::Extlang->new()->domain } : undef;
 
-sub _typespec {				## draft-levine-dnsextlang
-	eval <<'END' if EXTLANG && $DNSEXTLANG;## no critic
+sub _typespec {
+	eval {				## draft-levine-dnsextlang
+		<<'END' } if EXTLANG && $DNSEXTLANG;
 	my ($node) = @_;
 
 	require Net::DNS::Resolver;
