@@ -1,10 +1,8 @@
 package Net::DNS::Resolver::UNIX;
 
-#
-# $Id: UNIX.pm 1408 2015-10-06 20:35:56Z willem $
-#
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1408 $)[1];
+use strict;
+use warnings;
+our $VERSION = (qw$Id: UNIX.pm 1811 2020-10-05 08:24:23Z willem $)[2];
 
 
 =head1 NAME
@@ -14,39 +12,34 @@ Net::DNS::Resolver::UNIX - Unix resolver class
 =cut
 
 
-use strict;
 use base qw(Net::DNS::Resolver::Base);
 
 
-my $resolv_conf = "/etc/resolv.conf";
-my $dotfile	= '.resolv.conf';
+my @config_file = grep { -f $_ && -r _ } '/etc/resolv.conf';
 
-my @resolv_conf = grep -f $_ && -r _, $resolv_conf;
-
-my @config_path;
-push( @config_path, $ENV{HOME} ) if exists $ENV{HOME};
-push( @config_path, '.' );
-
-my @config_file = grep -f $_ && -o _, map "$_/$dotfile", @config_path;
+my $dotfile = '.resolv.conf';
+my @dotpath = grep {defined} $ENV{HOME}, '.';
+my @dotfile = grep { -f $_ && -o _ } map {"$_/$dotfile"} @dotpath;
 
 
-sub _untaint {
-	map { m/^(.*)$/; $1 } grep defined, @_;
-}
+local $ENV{PATH} = '/bin:/usr/bin';
+my $uname = eval {`uname -n 2>/dev/null`} || '';
+chomp $uname;
+my ( $host, @domain ) = split /\./, $uname, 2;
+__PACKAGE__->domain(@domain);
 
 
 sub _init {
 	my $defaults = shift->_defaults;
 
-	map $defaults->_read_config_file($_), @resolv_conf;
+	$defaults->_read_config_file($_) foreach @config_file;
 
-	foreach my $attr (qw(nameservers searchlist)) {
-		$defaults->$attr( _untaint $defaults->$attr() );
-	}
+	%$defaults = Net::DNS::Resolver::Base::_untaint(%$defaults);
 
-	map $defaults->_read_config_file($_), @config_file;
+	$defaults->_read_config_file($_) foreach @dotfile;
 
 	$defaults->_read_env;
+	return;
 }
 
 
