@@ -1,9 +1,8 @@
 package Net::DNS::Resolver::cygwin;
 
-#
-# $Id: cygwin.pm 1568 2017-05-27 06:40:20Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1568 $)[1];
+use strict;
+use warnings;
+our $VERSION = (qw$Id: cygwin.pm 1811 2020-10-05 08:24:23Z willem $)[2];
 
 
 =head1 NAME
@@ -13,28 +12,26 @@ Net::DNS::Resolver::cygwin - Cygwin resolver class
 =cut
 
 
-use strict;
-use warnings;
 use base qw(Net::DNS::Resolver::Base);
+use IO::File;
 
 
 sub _getregkey {
-	my $key = join '/', @_;
+	my @key = @_;
 
-	local *LM;
-	open( LM, "<$key" ) or return '';
-	my $value = <LM>;
-	$value =~ s/\0+$// if $value;
-	close(LM);
+	my $handle = IO::File->new( join( '/', @key ), '<' ) or return '';
+	my $value  = <$handle> || '';
+	close($handle);
 
-	return $value || '';
+	$value =~ s/\0+$//;
+	return $value;
 }
 
 
 sub _init {
 	my $defaults = shift->_defaults;
 
-	local *LM;
+	my $dirhandle;
 
 	my $root = '/proc/registry/HKEY_LOCAL_MACHINE/SYSTEM/CurrentControlSet/Services/Tcpip/Parameters';
 
@@ -60,7 +57,7 @@ sub _init {
 
 	# This is (probably) adequate on NT4
 	my @nt4nameservers;
-	foreach ( grep length, _getregkey( $root, 'NameServer' ), _getregkey( $root, 'DhcpNameServer' ) ) {
+	foreach ( grep {length} _getregkey( $root, 'NameServer' ), _getregkey( $root, 'DhcpNameServer' ) ) {
 		push @nt4nameservers, split m/[\s,]+/;
 		last;
 	}
@@ -75,9 +72,9 @@ sub _init {
 	my @nameservers;
 
 	my $dnsadapters = join '/', $root, 'DNSRegisteredAdapters';
-	if ( opendir( LM, $dnsadapters ) ) {
-		my @adapters = grep !/^\.\.?$/, readdir(LM);
-		closedir(LM);
+	if ( opendir( $dirhandle, $dnsadapters ) ) {
+		my @adapters = grep { !/^\.\.?$/ } readdir($dirhandle);
+		closedir($dirhandle);
 		foreach my $adapter (@adapters) {
 			my $ns = _getregkey( $dnsadapters, $adapter, 'DNSServerAddresses' );
 			until ( length($ns) < 4 ) {
@@ -88,9 +85,9 @@ sub _init {
 	}
 
 	my $interfaces = join '/', $root, 'Interfaces';
-	if ( opendir( LM, $interfaces ) ) {
-		my @ifacelist = grep !/^\.\.?$/, readdir(LM);
-		closedir(LM);
+	if ( opendir( $dirhandle, $interfaces ) ) {
+		my @ifacelist = grep { !/^\.\.?$/ } readdir($dirhandle);
+		closedir($dirhandle);
 		foreach my $iface (@ifacelist) {
 			my $ip = _getregkey( $interfaces, $iface, 'DhcpIPAddress' )
 					|| _getregkey( $interfaces, $iface, 'IPAddress' );
@@ -98,8 +95,7 @@ sub _init {
 			next if $ip eq '0.0.0.0';
 
 			foreach (
-				grep length,
-				_getregkey( $interfaces, $iface, 'NameServer' ),
+				grep {length} _getregkey( $interfaces, $iface, 'NameServer' ),
 				_getregkey( $interfaces, $iface, 'DhcpNameServer' )
 				) {
 				push @nameservers, split m/[\s,]+/;
@@ -132,6 +128,7 @@ sub _init {
 	%$defaults = Net::DNS::Resolver::Base::_untaint(%$defaults);
 
 	$defaults->_read_env;
+	return;
 }
 
 
